@@ -6,7 +6,7 @@ from mopidy import config, ext
 from mopidy.exceptions import ExtensionError
 
 
-__version__ = '2.0.2'
+__version__ = '2.1.0'
 
 
 class SoundCloudExtension(ext.Extension):
@@ -21,7 +21,7 @@ class SoundCloudExtension(ext.Extension):
 
     def get_config_schema(self):
         schema = super(SoundCloudExtension, self).get_config_schema()
-        schema['explore_songs'] = config.Integer()
+        schema['explore_songs'] = config.Integer(optional=True)
         schema['auth_token'] = config.Secret()
         schema['explore'] = config.Deprecated()
         schema['explore_pages'] = config.Deprecated()
