@@ -18,12 +18,17 @@ class SoundCloudBackend(pykka.ThreadingActor, backend.Backend):
     def __init__(self, config, audio):
         super(SoundCloudBackend, self).__init__()
         self.config = config
-        self.remote = SoundCloudClient(config['soundcloud'])
+        self.remote = SoundCloudClient(config)
         self.library = SoundCloudLibraryProvider(backend=self)
         self.playback = SoundCloudPlaybackProvider(audio=audio, backend=self)
 
         self.uri_schemes = ['soundcloud', 'sc']
 
+    def on_start(self):
+        username = self.remote.user.get('username')
+        if username is not None:
+            logger.info('Logged in to SoundCloud as "%s"', username)
+
 
 class SoundCloudPlaybackProvider(backend.PlaybackProvider):
 
